@@ -8,7 +8,7 @@ when /darwin/i; ["const_data", "g"]
 else ;["rdata", ""]
 end
 
-UNICODE_VERSION = "12.1.0"
+UNICODE_VERSION = "13.0.0"
 SRC_DIR = "../src/org/jcodings"
 DST_BIN_DIR =  "../resources/tables"
 INDENT = " " * 4
@@ -65,6 +65,7 @@ def generate_encoding_list
       "KOI8-R" =>       "KOI8R",
       "KOI8-U" =>       "KOI8U",
       "Shift_JIS" =>    "SJIS",
+      "CESU-8" =>       "CESU8",
       "UTF-16BE" =>     "UTF16BE",
       "UTF-16LE" =>     "UTF16LE",
       "UTF-32BE" =>     "UTF32BE",
@@ -78,7 +79,7 @@ def generate_encoding_list
       "Windows-1257" => "Windows_1257"
     }
 
-    defines, other = open("#{REPO_PATH}/encdb.h").read.tr('()', '').scan(/ENC_([A-Z_]+)(.*?);/m).reject{|a, b| b =~ /CESU/}.partition { |a, b| a =~ /DEFINE/ }
+    defines, other = open("#{REPO_PATH}/encdb.h").read.tr('()', '').scan(/ENC_([A-Z_]+)(.*?);/m).partition { |a, b| a =~ /DEFINE/ }
     other << ["ALIAS", "\"MS932\", \"Windows-31J\""]
     other << ["ALIAS", "\"UTF8\", \"UTF-8\""]
 
@@ -91,9 +92,10 @@ end
 
 def generate_transcoder_list
     generic_list = []
+    specific_list = []
     transcoder_list = []
 
-    Dir["#{REPO_PATH}/enc/trans/*.c"].reject{|f| f =~ /transdb/ || f =~ /cesu/}.sort.each do |trans_file|
+    Dir["#{REPO_PATH}/enc/trans/*.c"].reject{|f| f =~ /transdb/}.sort.each do |trans_file|
         name = trans_file[/(\w+)\.c/, 1].split('_').map{|e| e.capitalize}.join("")
         trans_src = open(trans_file){|f|f.read}
 
@@ -104,10 +106,14 @@ def generate_transcoder_list
             body = body.gsub(/(\/\*.*?\*\/)/, "").split(',').map{|e|e.strip}
             src, dst, tree_start, table_info, iul, max_in, max_out, conv, state_size, state_init, state_fini, *funcs = body
             tree_start = trans_src[/#define\s+#{tree_start}\s+WORDINDEX2INFO\((\d+)\)/, 1].to_i << 2
-            state_size = "0" if state_size == "sizeof(struct from_utf8_mac_status)"
-            generic = funcs.all?{|f|f == "NULL"}
+            state_size = "24" if state_size == "sizeof(struct from_utf8_mac_status)"
+            generic = funcs.all?{|f|f == "NULL" || f == "0"}
 
-            generic_list << [src, dst, tree_start, "\"#{name}\"", iul, max_in, max_out, "AsciiCompatibility.#{conv.split('_').last.upcase}", state_size] if generic
+            if generic
+              generic_list << [src, dst, tree_start, "\"#{name}\"", iul, max_in, max_out, "AsciiCompatibility.#{conv.split('_').last.upcase}", state_size]
+            else
+              specific_list << [t_name, src, dst, tree_start, "\"#{name}\"", iul, max_in, max_out, "AsciiCompatibility.#{conv.split('_').last.upcase}", state_size]
+            end
             transcoder_list << [src, dst, t_name, !generic]
         end
 
@@ -117,6 +123,20 @@ def generate_transcoder_list
         sub(/%\{generic\}/, generic_list.map{|g| "#{INDENT*2}new GenericTranscoderEntry(#{g.join(', ')})"}.join(",\n")).
         sub(/%\{switch\}/, transcoder_list.map{|src, dst, cls, specific| "#{INDENT*3}case \"#{cls}\": return #{cls}_Transcoder.INSTANCE;" if specific}.compact.join("\n"))
 
+    generate_specific_transcoder_data(specific_list)
+end
+
+def generate_specific_transcoder_data(specific_list)
+    specific_list.each do |transcoder|
+        path = "#{SRC_DIR}/transcode/specific/#{transcoder[0]}_Transcoder.java"
+        next unless File.exist?(path)
+
+        content = open(path, "rb"){ |f| f.read }
+        if content.match("super\\((.*)\\);")
+            content.sub!($1, transcoder[1..-1].join(", "))
+            open(path, "wb") << content
+        end
+    end
 end
 
 def generate_transoder_data
